redvox.cli API documentation

# Module `redvox.cli`

## Sub-modules

`redvox.cli.cli`

  This module provides a command line interface (CLI) for converting, viewing, and downloading RedVox data files.

`redvox.cli.conversions`

  This module contains functions for performing RedVox data conversions and displaying the contents of rdvxz files.

`redvox.cli.data_req`

  This module provides methods and classes for requesting bulk RedVox data.